==> ui-framework-4.14.8-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractFrameExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractFrameExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_0144050556 _7_1_0144050556;
	public FrameExamplesMold._7_1_0144050556. _8_2_01857056419 _8_2_01857056419;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419. _9_3_0308355687 _9_3_0308355687;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419. _10_3_11976527644 _10_3_11976527644;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644. _11_4_1727442191 _11_4_1727442191;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644. _12_4_0307652076 _12_4_0307652076;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644._12_4_0307652076. _12_12_01933515515 _12_12_01933515515;

    public AbstractFrameExamplesMold(B box) {
        super(box);
        id("frameExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_0144050556 == null) _7_1_0144050556 = register(new _7_1_0144050556(box()).<_7_1_0144050556>id("a2067634739").owner(AbstractFrameExamplesMold.this));
		if (_7_1_0144050556 != null) _8_2_01857056419 = _7_1_0144050556._8_2_01857056419;
		if (_8_2_01857056419 != null) _9_3_0308355687 = _7_1_0144050556._8_2_01857056419._9_3_0308355687;
		if (_8_2_01857056419 != null) _10_3_11976527644 = _7_1_0144050556._8_2_01857056419._10_3_11976527644;
		if (_10_3_11976527644 != null) _11_4_1727442191 = _7_1_0144050556._8_2_01857056419._10_3_11976527644._11_4_1727442191;
		if (_10_3_11976527644 != null) _12_4_0307652076 = _7_1_0144050556._8_2_01857056419._10_3_11976527644._12_4_0307652076;
		if (_12_4_0307652076 != null) _12_12_01933515515 = _7_1_0144050556._8_2_01857056419._10_3_11976527644._12_4_0307652076._12_12_01933515515;
	}

	public class _7_1_0144050556 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public FrameExamplesMold._7_1_0144050556. _8_2_01857056419 _8_2_01857056419;

		public _7_1_0144050556(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_01857056419 == null) _8_2_01857056419 = register(new _8_2_01857056419(box()).<_8_2_01857056419>id("a_973376039").owner(AbstractFrameExamplesMold.this));
		}

		public class _8_2_01857056419 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public FrameExamplesMold._7_1_0144050556._8_2_01857056419. _9_3_0308355687 _9_3_0308355687;
			public FrameExamplesMold._7_1_0144050556._8_2_01857056419. _10_3_11976527644 _10_3_11976527644;

			public _8_2_01857056419(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_1049083528").owner(AbstractFrameExamplesMold.this));
				if (_10_3_11976527644 == null) _10_3_11976527644 = register(new _10_3_11976527644(box()).<_10_3_11976527644>id("a683921889").owner(AbstractFrameExamplesMold.this));
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class _10_3_11976527644 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644. _11_4_1727442191 _11_4_1727442191;
				public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644. _12_4_0307652076 _12_4_0307652076;

				public _10_3_11976527644(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_11_4_1727442191 == null) _11_4_1727442191 = register(new _11_4_1727442191(box()).<_11_4_1727442191>id("a1813581927").owner(AbstractFrameExamplesMold.this));
					if (_12_4_0307652076 == null) _12_4_0307652076 = register(new _12_4_0307652076(box()).<_12_4_0307652076>id("a1011947498").owner(AbstractFrameExamplesMold.this));
				}

				public class _11_4_1727442191 extends io.intino.alexandria.ui.displays.components.Frame<io.intino.alexandria.ui.displays.notifiers.FrameNotifier, B>  {

					public _11_4_1727442191(B box) {
						super(box);
						_url("https://intino.io");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class _12_4_0307652076 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644._12_4_0307652076. _12_12_01933515515 _12_12_01933515515;

					public _12_4_0307652076(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (_12_12_01933515515 == null) _12_12_01933515515 = register(new _12_12_01933515515(box()).<_12_12_01933515515>id("a_101457744").owner(AbstractFrameExamplesMold.this));
					}

					public class _12_12_01933515515 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

						public _12_12_01933515515(B box) {
							super(box);
							_value("Frame(url=\"https://intino.io\")");
						}

						@Override
						public void init() {
							super.init();
						}
					}
				}
			}
		}
	}
}

==> ui-framework-4.17.9-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractFrameExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractFrameExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_0144050556 _7_1_0144050556;
	public FrameExamplesMold._7_1_0144050556. _8_2_01857056419 _8_2_01857056419;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419. _9_3_0308355687 _9_3_0308355687;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419. _10_3_11976527644 _10_3_11976527644;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644. _11_4_1727442191 _11_4_1727442191;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644. _12_4_0307652076 _12_4_0307652076;
	public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644._12_4_0307652076. _12_12_01933515515 _12_12_01933515515;

    public AbstractFrameExamplesMold(B box) {
        super(box);
        id("frameExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_0144050556 == null) _7_1_0144050556 = register(new _7_1_0144050556(box()).<_7_1_0144050556>id("a2067634739").owner(AbstractFrameExamplesMold.this));
		if (_7_1_0144050556 != null) _8_2_01857056419 = _7_1_0144050556._8_2_01857056419;
		if (_8_2_01857056419 != null) _9_3_0308355687 = _7_1_0144050556._8_2_01857056419._9_3_0308355687;
		if (_8_2_01857056419 != null) _10_3_11976527644 = _7_1_0144050556._8_2_01857056419._10_3_11976527644;
		if (_10_3_11976527644 != null) _11_4_1727442191 = _7_1_0144050556._8_2_01857056419._10_3_11976527644._11_4_1727442191;
		if (_10_3_11976527644 != null) _12_4_0307652076 = _7_1_0144050556._8_2_01857056419._10_3_11976527644._12_4_0307652076;
		if (_12_4_0307652076 != null) _12_12_01933515515 = _7_1_0144050556._8_2_01857056419._10_3_11976527644._12_4_0307652076._12_12_01933515515;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_7_1_0144050556 != null) _7_1_0144050556.unregister();
	}

	public class _7_1_0144050556 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public FrameExamplesMold._7_1_0144050556. _8_2_01857056419 _8_2_01857056419;

		public _7_1_0144050556(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_01857056419 == null) _8_2_01857056419 = register(new _8_2_01857056419(box()).<_8_2_01857056419>id("a_973376039").owner(AbstractFrameExamplesMold.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_8_2_01857056419 != null) _8_2_01857056419.unregister();
		}

		public class _8_2_01857056419 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public FrameExamplesMold._7_1_0144050556._8_2_01857056419. _9_3_0308355687 _9_3_0308355687;
			public FrameExamplesMold._7_1_0144050556._8_2_01857056419. _10_3_11976527644 _10_3_11976527644;

			public _8_2_01857056419(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_1049083528").owner(AbstractFrameExamplesMold.this));
				if (_10_3_11976527644 == null) _10_3_11976527644 = register(new _10_3_11976527644(box()).<_10_3_11976527644>id("a683921889").owner(AbstractFrameExamplesMold.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_9_3_0308355687 != null) _9_3_0308355687.unregister();
				if (_10_3_11976527644 != null) _10_3_11976527644.unregister();
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class _10_3_11976527644 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644. _11_4_1727442191 _11_4_1727442191;
				public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644. _12_4_0307652076 _12_4_0307652076;

				public _10_3_11976527644(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_11_4_1727442191 == null) _11_4_1727442191 = register(new _11_4_1727442191(box()).<_11_4_1727442191>id("a1813581927").owner(AbstractFrameExamplesMold.this));
					if (_12_4_0307652076 == null) _12_4_0307652076 = register(new _12_4_0307652076(box()).<_12_4_0307652076>id("a1011947498").owner(AbstractFrameExamplesMold.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_11_4_1727442191 != null) _11_4_1727442191.unregister();
					if (_12_4_0307652076 != null) _12_4_0307652076.unregister();
				}

				public class _11_4_1727442191 extends io.intino.alexandria.ui.displays.components.Frame<io.intino.alexandria.ui.displays.notifiers.FrameNotifier, B>  {

					public _11_4_1727442191(B box) {
						super(box);
						_url("https://intino.io");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class _12_4_0307652076 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public FrameExamplesMold._7_1_0144050556._8_2_01857056419._10_3_11976527644._12_4_0307652076. _12_12_01933515515 _12_12_01933515515;

					public _12_4_0307652076(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (_12_12_01933515515 == null) _12_12_01933515515 = register(new _12_12_01933515515(box()).<_12_12_01933515515>id("a_101457744").owner(AbstractFrameExamplesMold.this));
					}

					@Override
					public void unregister() {
					    super.unregister();
						if (_12_12_01933515515 != null) _12_12_01933515515.unregister();
					}

					public class _12_12_01933515515 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

						public _12_12_01933515515(B box) {
							super(box);
							_value("Frame(url=\"https://intino.io\")");
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public void unregister() {
						    super.unregister();
						}
					}
				}
			}
		}
	}
}
